@@ -6,3 +6,8 @@ from abstract_gui.QT6.imports import (
     QTableWidget, QTableWidgetItem, QVBoxLayout, QWidget,
     QAbstractItemView
 )
+from PyQt6.QtGui import QColor, QBrush
+from PyQt6.QtWidgets import QMessageBox
+from PyQt6.QtCore import Qt
+SB = QMessageBox.StandardButton
+IDR = Qt.ItemDataRole
